import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:medapp_eksad/api/userControl_api.dart';

class UserControl extends StatefulWidget {
  const UserControl({Key? key}) : super(key: key);

  @override
  State<UserControl> createState() => _UserControlState();
}

class _UserControlState extends State<UserControl> {
  final formKey = GlobalKey<FormState>();

  @override
  Widget build(BuildContext context) {
    var screenSize = MediaQuery.of(context).size;
    return Padding(
      padding: const EdgeInsets.all(30.0),
      child: Container(
        padding: const EdgeInsets.symmetric(horizontal: 10),
        decoration: BoxDecoration(
            color: Colors.white60,
            borderRadius: BorderRadius.circular(20),
            boxShadow: [
              BoxShadow(
                  color: const Color.fromARGB(255, 10, 116, 255).withAlpha(60),
                  blurRadius: 5.0,
                  spreadRadius: 5.0,
                  offset: const Offset(0.0, 3.0))
            ]),
        child: Column(
          children: [
            Container(
              height: screenSize.height * 0.15,
              child: Center(
                child: Text(
                  'Data User',
                  style: GoogleFonts.poppins(
                      height: 1.5,
                      fontSize: 31,
                      fontWeight: FontWeight.bold,
                      color: Colors.blueAccent[200]),
                ),
              ),
            ),
            Container(
              height: screenSize.height * 0.65,
              child: ListView(
                controller: ScrollController(),
                children: [
                  FutureBuilder<List<dynamic>>(
                      future: getUserControl(),
                      builder: (BuildContext context, AsyncSnapshot snapshot) {
                        if (snapshot.hasError ||
                            snapshot.data == null ||
                            snapshot.connectionState ==
                                ConnectionState.waiting) {
                          return const CircularProgressIndicator();
                        }
                        return DataTable(
                            decoration:
                            const BoxDecoration(color: Colors.white),
                            columnSpacing: 55,
                            columns: const [
                              DataColumn(
                                  label: Text(
                                    "ID",
                                    style: TextStyle(fontWeight: FontWeight.bold),
                                  )),
                              DataColumn(
                                  label: Text(
                                    "Nama Rumah Sakit",
                                    style: TextStyle(fontWeight: FontWeight.bold),
                                  )),
                              // DataColumn(label: Text("Telp Rumah Sakit")),
                              DataColumn(
                                  label: Text(
                                    "Alamat Rumah Sakit",
                                    style: TextStyle(fontWeight: FontWeight.bold),
                                  )),
                              // DataColumn(label: Text("Nama PIC")),
                              // DataColumn(label: Text("Telp PIC")),
                              // DataColumn(label: Text("Email PIC")),
                              DataColumn(
                                  label: Text(
                                    "STATUS",
                                    style: TextStyle(fontWeight: FontWeight.bold),
                                  )),
                              DataColumn(
                                  label: Text(
                                    "ACTION",
                                    style: TextStyle(fontWeight: FontWeight.bold),
                                  ))
                            ],
                            rows: List.generate(snapshot.data.length, (index) {
                              var pgm = snapshot.data[index];

                              return DataRow(cells: [
                                DataCell(Text(pgm['idUser'].toString())),
                                DataCell(Text(pgm['namaRs'].toString())),
                                // DataCell(Text(pgm['noRs'].toString())),
                                DataCell(Text(pgm['alamatRs'].toString())),
                                // DataCell(Text(pgm['namaPic'].toString())),
                                // DataCell(Text(pgm['noPic'].toString())),
                                // DataCell(Text(pgm['emailPic'].toString())),
                                DataCell(Text(pgm['statusUser'].toString())),
                                DataCell(PopupMenuButton(
                                    icon: Icon(Icons.more_vert_outlined),
                                    itemBuilder: (context) => [
                                      PopupMenuItem(
                                          child: Text("Edit"), value: 1),
                                      PopupMenuItem(
                                          child: Text("Delete"), value: 2),
                                      PopupMenuItem(
                                          child: Text("View"), value: 3)
                                    ]))
                              ]);
                            }).toList());
                      })
                ],
              ),
            )
          ],
        ),
      ),
    );
  }
}
